To do list
==========

- `Static code analysis to get source of objects used in functions/methods
  <https://bitbucket.org/fluiddyn/fluidpythran/issues/18/>`_ for a nicer user
  API.

- `Alternative syntax for blocks with decorator and context manager
  <https://bitbucket.org/fluiddyn/fluidpythran/issues/29>`_

- Type hints: `Shape <https://bitbucket.org/fluiddyn/fluidpythran/issues/12>`_

.. toctree::
   :maxdepth: 2

   universal_booster

Inline to do items
------------------

.. todolist::
